@@ -26,9 +26,10 @@
 """
 
 from Note import Note
+from NoteContainer import NoteContainer
 from Bar import Bar
 from Track import Track
 from Composition import Composition
 from Suite import Suite
+from Instrument import Instrument, Piano, Guitar
 
-__all__ = ["NoteContainers"]
