@@ -166,6 +166,8 @@ def melodic_minor(note):
 	har[5] = notes.augment(har[5])
 	return har
 
+# Other scales
+
 def chromatic(note):
 	return map(lambda x: intervals.get_interval(note, x), range(0,12))
 
@@ -187,5 +189,18 @@ def whole_note(note):
 		n += 1
 	return res
 
+def diminished(note):
+	def whole_step_half_step(n):
+		res = [intervals.major_second(n), intervals.minor_third(n)]
+		return res
+
+	res = [note]
+	for i in range(3):
+		res += whole_step_half_step(note)
+		note = res[-1]
+
+	res = res + [intervals.major_seventh(res[0])]
+	res[-2] = intervals.major_sixth(res[0])
+	return res
 
 	
